==> google_applovin_unity_ads-2.1.1.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterAdListener.java <==
// Copyright 2022 Bitcoding
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.applovin.mediation.MaxAd;
import com.applovin.mediation.MaxAdViewAdListener;
import com.applovin.mediation.MaxError;
import com.applovin.mediation.nativeAds.MaxNativeAdListener;
import com.applovin.mediation.nativeAds.MaxNativeAdView;
import com.google.android.gms.ads.AdListener;
import com.google.android.gms.ads.LoadAdError;
import com.google.android.gms.ads.nativead.NativeAd;
import com.google.android.gms.ads.nativead.NativeAd.OnNativeAdLoadedListener;

import java.lang.ref.WeakReference;

/** Callback type to notify when an ad successfully loads. */
interface FlutterAdLoadedListener {
  void onAdLoaded();
}

class FlutterAdListener extends AdListener {
  protected final int adId;
  @NonNull protected final AdInstanceManager manager;

  FlutterAdListener(int adId, @NonNull AdInstanceManager manager) {
    this.adId = adId;
    this.manager = manager;
  }

  @Override
  public void onAdClosed() {
    manager.onAdClosed(adId);
  }

  @Override
  public void onAdFailedToLoad(LoadAdError loadAdError) {
    manager.onAdFailedToLoad(adId, new FlutterAd.FlutterLoadAdError(loadAdError));
  }

  @Override
  public void onAdOpened() {
    manager.onAdOpened(adId);
  }

  @Override
  public void onAdImpression() {
    manager.onAdImpression(adId);
  }

  @Override
  public void onAdClicked() {
    manager.onAdClicked(adId);
  }
}

/**
 * Ad listener for banner ads. Does not override onAdClicked(), since that is only for native ads.
 */
class FlutterBannerAdListener extends FlutterAdListener implements MaxAdViewAdListener {

  @NonNull final WeakReference<FlutterAdLoadedListener> adLoadedListenerWeakReference;
  @NonNull final AdInstanceManager manager;

  FlutterBannerAdListener(
      int adId, @NonNull AdInstanceManager manager, FlutterAdLoadedListener adLoadedListener) {
    super(adId, manager);
    this.manager = manager;
    adLoadedListenerWeakReference = new WeakReference<>(adLoadedListener);
  }

  @Override
  public void onAdLoaded() {
    if (adLoadedListenerWeakReference.get() != null) {
      adLoadedListenerWeakReference.get().onAdLoaded();
    }
  }

  @Override
  public void onAdExpanded(MaxAd ad) {

  }

  @Override
  public void onAdCollapsed(MaxAd ad) {

  }

  @Override
  public void onAdLoaded(MaxAd ad) {
    if (adLoadedListenerWeakReference.get() != null) {
      adLoadedListenerWeakReference.get().onAdLoaded();
    }
  }

  @Override
  public void onAdDisplayed(MaxAd ad) {
    manager.onAdShowedFullScreenContent(adId);
  }

  @Override
  public void onAdHidden(MaxAd ad) {
    manager.onAdDismissedFullScreenContent(adId);
  }

  @Override
  public void onAdClicked(MaxAd ad) {
    manager.onAdClicked(adId);
  }

  @Override
  public void onAdLoadFailed(String adUnitId, MaxError error) {
    manager.onAdFailedToLoad(adId, new FlutterAd.FlutterLoadAdError(new LoadAdError(error.getCode(), error.getMessage(), error.getMediatedNetworkErrorMessage(),null, null)));
  }

  @Override
  public void onAdDisplayFailed(MaxAd ad, MaxError error) {
    manager.onAdDismissedFullScreenContent(adId);
  }
}

/** Listener for native ads. */
class FlutterNativeAdListener extends FlutterAdListener {

  FlutterNativeAdListener(int adId, AdInstanceManager manager) {
    super(adId, manager);
  }

  @Override
  public void onAdLoaded() {
    // Do nothing. Loaded event is handled from FlutterNativeAdLoadedListener.
  }
}

/** {@link OnNativeAdLoadedListener} for native ads. */
class FlutterNativeAdLoadedListener implements OnNativeAdLoadedListener {

  private final WeakReference<FlutterNativeAd> nativeAdWeakReference;


  FlutterNativeAdLoadedListener(FlutterNativeAd flutterNativeAd) {
    nativeAdWeakReference = new WeakReference<>(flutterNativeAd);
  }

  @Override
  public void onNativeAdLoaded(@NonNull NativeAd nativeAd) {
    if (nativeAdWeakReference.get() != null) {
      nativeAdWeakReference.get().onNativeAdLoaded(nativeAd);
    }
  }
}


/** {@link OnNativeAdLoadedListener} for native ads. */
class FlutterAppLovinNativeAdLoadedListener extends MaxNativeAdListener {

  private final WeakReference<FlutterAppLovinNativeAd> nativeAdWeakReference;

  FlutterAppLovinNativeAdLoadedListener(FlutterAppLovinNativeAd flutterNativeAd) {
    nativeAdWeakReference = new WeakReference<>(flutterNativeAd);
  }


  @Override
  public void onNativeAdLoaded(@Nullable MaxNativeAdView maxNativeAdView, MaxAd maxAd) {
    super.onNativeAdLoaded(maxNativeAdView, maxAd);
    if (nativeAdWeakReference.get() != null) {
      nativeAdWeakReference.get().onNativeAdLoaded();
    }
  }

  @Override
  public void onNativeAdLoadFailed(String s, MaxError error) {
    super.onNativeAdLoadFailed(s, error);
    if (nativeAdWeakReference.get() != null) {
      nativeAdWeakReference.get().onNativeAdFailedToLoad(error);
    }
  }

  @Override
  public void onNativeAdClicked(MaxAd maxAd) {
    super.onNativeAdClicked(maxAd);
    if (nativeAdWeakReference.get() != null) {
      nativeAdWeakReference.get().onNativeAdClicked();
    }
  }

  @Override
  public void onNativeAdExpired(MaxAd maxAd) {
    super.onNativeAdExpired(maxAd);
  }

}

==> google_applovin_unity_ads-2.2.2.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterAdListener.java <==
// Copyright 2022 Bitcoding
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.applovin.mediation.MaxAd;
import com.applovin.mediation.MaxAdViewAdListener;
import com.applovin.mediation.MaxError;
import com.applovin.mediation.nativeAds.MaxNativeAdListener;
import com.applovin.mediation.nativeAds.MaxNativeAdView;
import com.facebook.ads.Ad;
import com.facebook.ads.AdError;
import com.facebook.ads.NativeAdListener;
import com.google.android.gms.ads.AdListener;
import com.google.android.gms.ads.LoadAdError;
import com.google.android.gms.ads.nativead.NativeAd;
import com.google.android.gms.ads.nativead.NativeAd.OnNativeAdLoadedListener;

import java.lang.ref.WeakReference;

/** Callback type to notify when an ad successfully loads. */
interface FlutterAdLoadedListener {
  void onAdLoaded();
}

class FlutterAdListener extends AdListener {
  protected final int adId;
  @NonNull protected final AdInstanceManager manager;

  FlutterAdListener(int adId, @NonNull AdInstanceManager manager) {
    this.adId = adId;
    this.manager = manager;
  }

  @Override
  public void onAdClosed() {
    manager.onAdClosed(adId);
  }

  @Override
  public void onAdFailedToLoad(LoadAdError loadAdError) {
    manager.onAdFailedToLoad(adId, new FlutterAd.FlutterLoadAdError(loadAdError));
  }

  @Override
  public void onAdOpened() {
    manager.onAdOpened(adId);
  }

  @Override
  public void onAdImpression() {
    manager.onAdImpression(adId);
  }

  @Override
  public void onAdClicked() {
    manager.onAdClicked(adId);
  }
}

/**
 * Ad listener for banner ads. Does not override onAdClicked(), since that is only for native ads.
 */
class FlutterBannerAdListener extends FlutterAdListener implements MaxAdViewAdListener, com.facebook.ads.AdListener {

  @NonNull final WeakReference<FlutterAdLoadedListener> adLoadedListenerWeakReference;
  @NonNull final AdInstanceManager manager;

  FlutterBannerAdListener(
      int adId, @NonNull AdInstanceManager manager, FlutterAdLoadedListener adLoadedListener) {
    super(adId, manager);
    this.manager = manager;
    adLoadedListenerWeakReference = new WeakReference<>(adLoadedListener);
  }

  @Override
  public void onAdLoaded() {
    if (adLoadedListenerWeakReference.get() != null) {
      adLoadedListenerWeakReference.get().onAdLoaded();
    }
  }

  @Override
  public void onAdExpanded(MaxAd ad) {

  }

  @Override
  public void onAdCollapsed(MaxAd ad) {

  }

  @Override
  public void onAdLoaded(MaxAd ad) {
    if (adLoadedListenerWeakReference.get() != null) {
      adLoadedListenerWeakReference.get().onAdLoaded();
    }
  }

  @Override
  public void onAdDisplayed(MaxAd ad) {
    manager.onAdShowedFullScreenContent(adId);
  }

  @Override
  public void onAdHidden(MaxAd ad) {
    manager.onAdDismissedFullScreenContent(adId);
  }

  @Override
  public void onAdClicked(MaxAd ad) {
    manager.onAdClicked(adId);
  }

  @Override
  public void onAdLoadFailed(String adUnitId, MaxError error) {
    manager.onAdFailedToLoad(adId, new FlutterAd.FlutterLoadAdError(new LoadAdError(error.getCode(), error.getMessage(), error.getMediatedNetworkErrorMessage(),null, null)));
  }

  @Override
  public void onAdDisplayFailed(MaxAd ad, MaxError error) {
    manager.onAdDismissedFullScreenContent(adId);
  }

  @Override
  public void onError(Ad ad, AdError error) {
    manager.onAdFailedToLoad(adId, new FlutterAd.FlutterLoadAdError(new LoadAdError(error.getErrorCode(), error.getErrorMessage(), "facebook.com",null, null)));
  }

  @Override
  public void onAdLoaded(Ad ad) {
    if (adLoadedListenerWeakReference.get() != null) {
      adLoadedListenerWeakReference.get().onAdLoaded();
    }
  }

  @Override
  public void onAdClicked(Ad ad) {
    manager.onAdClicked(adId);
  }

  @Override
  public void onLoggingImpression(Ad ad) {
    manager.onAdImpression(adId);
  }
}

/** Listener for native ads. */
class FlutterNativeAdListener extends FlutterAdListener {

  FlutterNativeAdListener(int adId, AdInstanceManager manager) {
    super(adId, manager);
  }

  @Override
  public void onAdLoaded() {
    // Do nothing. Loaded event is handled from FlutterNativeAdLoadedListener.
  }
}

/** {@link OnNativeAdLoadedListener} for native ads. */
class FlutterNativeAdLoadedListener implements OnNativeAdLoadedListener {

  private final WeakReference<FlutterNativeAd> nativeAdWeakReference;


  FlutterNativeAdLoadedListener(FlutterNativeAd flutterNativeAd) {
    nativeAdWeakReference = new WeakReference<>(flutterNativeAd);
  }

  @Override
  public void onNativeAdLoaded(@NonNull NativeAd nativeAd) {
    if (nativeAdWeakReference.get() != null) {
      nativeAdWeakReference.get().onNativeAdLoaded(nativeAd);
    }
  }
}


/** {@link OnNativeAdLoadedListener} for native ads. */
class FlutterFacebookNativeAdLoadedListener implements NativeAdListener {

  private final WeakReference<FlutterFacebookNativeAd> nativeAdWeakReference;


  FlutterFacebookNativeAdLoadedListener(FlutterFacebookNativeAd flutterNativeAd) {
    nativeAdWeakReference = new WeakReference<>(flutterNativeAd);
  }

  @Override
  public void onMediaDownloaded(Ad ad) {

  }

  @Override
  public void onError(Ad ad, AdError adError) {
    if (nativeAdWeakReference.get() != null) {
      nativeAdWeakReference.get().onNativeAdFailedToLoad(adError);
    }
  }

  @Override
  public void onAdLoaded(Ad ad) {
    if (nativeAdWeakReference.get() != null) {
      nativeAdWeakReference.get().onNativeAdLoaded();
    }
  }

  @Override
  public void onAdClicked(Ad ad) {
    if (nativeAdWeakReference.get() != null) {
      nativeAdWeakReference.get().onNativeAdClicked();
    }
  }

  @Override
  public void onLoggingImpression(Ad ad) {
    if (nativeAdWeakReference.get() != null) {
      nativeAdWeakReference.get().onLoggingImpression();
    }
  }
}


/** {@link OnNativeAdLoadedListener} for native ads. */
class FlutterAppLovinNativeAdLoadedListener extends MaxNativeAdListener {

  private final WeakReference<FlutterAppLovinNativeAd> nativeAdWeakReference;

  FlutterAppLovinNativeAdLoadedListener(FlutterAppLovinNativeAd flutterNativeAd) {
    nativeAdWeakReference = new WeakReference<>(flutterNativeAd);
  }


  @Override
  public void onNativeAdLoaded(@Nullable MaxNativeAdView maxNativeAdView, MaxAd maxAd) {
    super.onNativeAdLoaded(maxNativeAdView, maxAd);
    if (nativeAdWeakReference.get() != null) {
      nativeAdWeakReference.get().onNativeAdLoaded();
    }
  }

  @Override
  public void onNativeAdLoadFailed(String s, MaxError error) {
    super.onNativeAdLoadFailed(s, error);
    if (nativeAdWeakReference.get() != null) {
      nativeAdWeakReference.get().onNativeAdFailedToLoad(error);
    }
  }

  @Override
  public void onNativeAdClicked(MaxAd maxAd) {
    super.onNativeAdClicked(maxAd);
    if (nativeAdWeakReference.get() != null) {
      nativeAdWeakReference.get().onNativeAdClicked();
    }
  }

  @Override
  public void onNativeAdExpired(MaxAd maxAd) {
    super.onNativeAdExpired(maxAd);
  }

}
